@@ -709,7 +709,7 @@ pgm_canvas_set_order (PgmCanvas *canvas,
   /* Same position in the list checking */
   if (data == drawable)
     {
-      GST_DEBUG_OBJECT (canvas, "'%s' is already at position %s",
+      GST_DEBUG_OBJECT (canvas, "'%s' is already at position %d",
                         GST_OBJECT_NAME (drawable), order);
       goto nothing_to_do;
     }
@@ -1087,3 +1087,50 @@ _pgm_canvas_remove_pixel_formats (PgmCanvas *canvas,
 
   GST_OBJECT_UNLOCK (canvas);
 }
+
+
+/**
+ * _pgm_canvas_get_entered_emission_stopper:
+ * @canvas: a #PgmCanvas instance.
+ *
+ * This function is only used internally by _pgm_drawable_do_motion_event() to
+ * get the #PgmDrawable::entered emission stopper, that is, the #PgmDrawable
+ * for which the callback connected to #PgmDrawable::entered returned TRUE.
+ *
+ * Returns: a #PgmDrawable instance, without a reference to it.
+ */
+PgmDrawable*
+_pgm_canvas_get_entered_emission_stopper (PgmCanvas *canvas)
+{
+  PgmDrawable *entered_emission_stopper;
+
+  g_return_val_if_fail (PGM_IS_CANVAS (canvas), NULL);
+
+  GST_OBJECT_LOCK (canvas);
+  entered_emission_stopper = canvas->entered_emission_stopper;
+  GST_OBJECT_UNLOCK (canvas);
+
+  return entered_emission_stopper;
+}
+
+/**
+ * _pgm_canvas_set_entered_emission_stopper:
+ * @canvas: a #PgmCanvas instance.
+ * @drawable: a #PgmCanvas instance.
+ *
+ * This function is only used internally by _pgm_drawable_do_motion_event() to
+ * set the #PgmDrawable::entered emission stopper, that is, the #PgmDrawable
+ * for which the callback connected to #PgmDrawable::entered returned TRUE.
+ *
+ * MT safe.
+ */
+void
+_pgm_canvas_set_entered_emission_stopper (PgmCanvas *canvas,
+                                          PgmDrawable *drawable)
+{
+  g_return_if_fail (PGM_IS_CANVAS (canvas));
+
+  GST_OBJECT_LOCK (canvas);
+  canvas->entered_emission_stopper = drawable;
+  GST_OBJECT_UNLOCK (canvas);
+}
