@@ -144,7 +144,7 @@ update_transformation_matrix (PgmDrawable *drawable)
   drawable->flags &= ~(PGM_DRAWABLE_PLANE_VECTORS | PGM_DRAWABLE_ORIGIN);
 }
 
-/* Update plane_vector_i and plane_vector_j if needed. Called with LOCK */
+/* Update plane_vector_i and plane_vector_j if needed. Called with LOCK. */
 static void
 update_plane_vectors (PgmDrawable *drawable)
 {
@@ -174,7 +174,7 @@ update_plane_vectors (PgmDrawable *drawable)
   pgm_vec4_free (drawable_j);
 }
 
-/* Update origin if needed. Called with LOCK */
+/* Update origin if needed. Called with LOCK. */
 static void
 update_origin (PgmDrawable *drawable)
 {
@@ -196,10 +196,24 @@ update_origin (PgmDrawable *drawable)
   pgm_vec4_free (origin4);
 }
 
+/* Check whether or not the drag distance has been covered.
+ * Called with LOCK. */
+static gboolean
+is_drag_distance_covered (PgmDrawable *drawable,
+                          PgmEventMotion *event)
+{
+  guchar x_distance =
+    (guchar) fabs (drawable->viewport_press_point.v[0] - event->x);
+  guchar y_distance =
+    (guchar) fabs (drawable->viewport_press_point.v[1] - event->y);
+
+  return (x_distance > drawable->drag_distance ||
+          y_distance > drawable->drag_distance);
+}
+
 /* Store the intersection between the plane defined by the drawable and a
  * line given by two points. Returns whether or not the intersection belongs
- * to the drawable.
- * Takes object LOCK. */
+ * to the drawable. */
 static gboolean
 get_line_intersection (PgmDrawable *drawable,
                        PgmVec3 *intersection,
@@ -207,9 +221,8 @@ get_line_intersection (PgmDrawable *drawable,
                        PgmVec3 *p2)
 {
   gboolean belongs = FALSE;
-  PgmVec3 origin, i, j;
   PgmVec3 *v;
-  gfloat x, y, width, height;
+  gfloat x, y;
 
   GST_OBJECT_LOCK (drawable);
 
@@ -218,16 +231,12 @@ get_line_intersection (PgmDrawable *drawable,
   if (! (drawable->flags & PGM_DRAWABLE_ORIGIN))
     update_origin (drawable);
 
-  pgm_vec3_set_from_vec3 (&origin, &drawable->origin);
-  pgm_vec3_set_from_vec3 (&i, &drawable->plane_vector_i);
-  pgm_vec3_set_from_vec3 (&j, &drawable->plane_vector_j);
-  width = drawable->width;
-  height = drawable->height;
-
   GST_OBJECT_UNLOCK (drawable);
 
   /* Get intersection with the plane */
-  v = pgm_intersection_line_plane (p1, p2, &origin, &i, &j);
+  v = pgm_intersection_line_plane (p1, p2, &drawable->origin,
+                                   &drawable->plane_vector_i,
+                                   &drawable->plane_vector_j);
   if (!v)
     return FALSE;
 
@@ -236,7 +245,8 @@ get_line_intersection (PgmDrawable *drawable,
 
   /* Test if the intersection belongs to the drawable rectangle */
   pgm_drawable_from_canvas (drawable, &x, &y, v->v[0], v->v[1], v->v[2]);
-  belongs = (x >= 0.0f && x <= width && y >= 0.0f && y <= height);
+  belongs = (x >= 0.0f && x <= drawable->width &&
+             y >= 0.0f && y <= drawable->height);
 
   pgm_vec3_free (v);
 
@@ -654,7 +664,9 @@ pgm_drawable_init (PgmDrawable *drawable)
   drawable->opacity = 255;
   /* Private data */
   pgm_vec3_set_from_scalars (&drawable->press_point, 0.0f, 0.0f, 0.0f);
+  pgm_vec3_set_from_scalars (&drawable->viewport_press_point, 0.0f, 0.0f, 0.0f);
   drawable->drag_mask = 0;
+  drawable->drag_distance = 5;
   drawable->press_mask = 0;
   drawable->pressure = 0;
   drawable->release_time = 0;
@@ -1357,24 +1369,6 @@ pgm_drawable_set_opacity (PgmDrawable *drawable,
   return ret;
 }
 
-/**
- * pgm_drawable_regenerate:
- * @drawable: a #PgmDrawable object.
- *
- * Forces a regeneration of the drawable.
- *
- * MT safe.
- *
- * Returns: a #PgmError indicating success/failure.
- */
-PgmError
-pgm_drawable_regenerate (PgmDrawable *drawable)
-{
-  _pgm_drawable_emit_changed (drawable, PGM_DRAWABLE_REGENERATE);
-
-  return PGM_ERROR_OK;
-}
-
 /**
  * pgm_drawable_get_opacity:
  * @drawable: a #PgmDrawable object.
@@ -1400,6 +1394,76 @@ pgm_drawable_get_opacity (PgmDrawable *drawable,
   return PGM_ERROR_OK;
 }
 
+/**
+ * pgm_drawable_set_drag_distance:
+ * @drawable: a #PgmDrawable object.
+ * @distance: the drag distance of @drawable. 5 by default.
+ *
+ * Defines the drag distance of @drawable to @distance. The drag distance is the
+ * distance in pixels the user has to cover with a mouse button pressed to
+ * trigger the <link linkend="PgmDrawable-drag-begin">'drag-begin'</link> signal.
+ *
+ * MT safe.
+ *
+ * Returns: a #PgmError indicating success/failure.
+ */
+PgmError
+pgm_drawable_set_drag_distance (PgmDrawable *drawable,
+                                guchar distance)
+{
+  g_return_val_if_fail (PGM_IS_DRAWABLE (drawable), PGM_ERROR_X);
+
+  GST_OBJECT_LOCK (drawable);
+  drawable->drag_distance = distance;
+  GST_OBJECT_UNLOCK (drawable);
+
+  return PGM_ERROR_OK;
+}
+
+/**
+ * pgm_drawable_get_drag_distance:
+ * @drawable: a #PgmDrawable object.
+ * @distance: a pointer to a #guchar where the drag distance is going to be
+ * stored.
+ *
+ * Retrieves the drag distance of @drawable in @distance.
+ *
+ * MT safe.
+ *
+ * Returns: a #PgmError indicating success/failure.
+ */
+PgmError
+pgm_drawable_get_drag_distance (PgmDrawable *drawable,
+                                guchar *distance)
+{
+  g_return_val_if_fail (PGM_IS_DRAWABLE (drawable), PGM_ERROR_X);
+  g_return_val_if_fail (distance != NULL, PGM_ERROR_X);
+
+  GST_OBJECT_LOCK (drawable);
+  *distance = drawable->drag_distance;
+  GST_OBJECT_UNLOCK (drawable);
+
+  return PGM_ERROR_OK;
+}
+
+/**
+ * pgm_drawable_regenerate:
+ * @drawable: a #PgmDrawable object.
+ *
+ * Forces a regeneration of the drawable.
+ *
+ * MT safe.
+ *
+ * Returns: a #PgmError indicating success/failure.
+ */
+PgmError
+pgm_drawable_regenerate (PgmDrawable *drawable)
+{
+  _pgm_drawable_emit_changed (drawable, PGM_DRAWABLE_REGENERATE);
+
+  return PGM_ERROR_OK;
+}
+
 /**
  * pgm_drawable_from_canvas:
  * @drawable: a #PgmDrawable object.
@@ -1561,6 +1625,8 @@ _pgm_drawable_do_press_event (PgmDrawable *drawable,
     {
       drawable->press_mask |= event->button;
       pgm_vec3_set_from_vec3 (&drawable->press_point, &intersect);
+      pgm_vec3_set_from_scalars (&drawable->viewport_press_point,
+                                 event->x, event->y, 0.0f);
 
       if (*emission_mask & PGM_DRAWABLE_PICKING_PRESSED)
         {
@@ -1677,8 +1743,10 @@ _pgm_drawable_do_release_event (PgmDrawable *drawable,
             *emission_mask &= ~PGM_DRAWABLE_PICKING_RELEASED;
         }
 
-      /* Emit a click if the cursor is over the drawable */
-      if (*emission_mask & PGM_DRAWABLE_PICKING_CLICKED)
+      /* Emit a click if the cursor is over the drawable. Take care of not
+       * emitting it if there's an on-going drag. */
+      if (!(drawable->drag_mask & event->button)
+          && *emission_mask & PGM_DRAWABLE_PICKING_CLICKED)
         {
           if (!cached)
             {
@@ -1796,7 +1864,8 @@ _pgm_drawable_do_motion_event (PgmDrawable *drawable,
           if (drawable->press_mask & button)
             {
               /* Emit the drag begin signal if there's no on-going drag */
-              if (!(drawable->drag_mask & button))
+              if (!(drawable->drag_mask & button)
+                  && is_drag_distance_covered (drawable, event))
                 {
                   drawable->drag_mask |= button;
 
@@ -1817,7 +1886,8 @@ _pgm_drawable_do_motion_event (PgmDrawable *drawable,
                 }
 
               /* Emit the drag motion signal */
-              if (*emission_mask & PGM_DRAWABLE_PICKING_DRAG_MOTION)
+              if ((*emission_mask & PGM_DRAWABLE_PICKING_DRAG_MOTION)
+                  && (drawable->drag_mask & button))
                 {
                   PgmVec3 intersect;
 
