@@ -80,6 +80,7 @@ typedef enum {
  * @PGM_DRAWABLE_FG_COLOR: %PgmDrawable foreground color property.
  * @PGM_DRAWABLE_OPACITY: %PgmDrawable opacity property.
  * @PGM_DRAWABLE_REGENERATE: %PgmDrawable regenerate property.
+ * @PGM_IMAGE_DATA_FILE: %PgmImage file data property.
  * @PGM_IMAGE_DATA_BUFFER: %PgmImage buffer data property.
  * @PGM_IMAGE_DATA_GST_BUFFER: %PgmImage GstBuffer data property.
  * @PGM_IMAGE_DATA_PIXBUF: %PgmImage GdkPixbuf data property.
@@ -91,6 +92,7 @@ typedef enum {
  * @PGM_IMAGE_ALIGNMENT: %PgmImage alignment property.
  * @PGM_IMAGE_LAYOUT: %PgmImage layout property.
  * @PGM_IMAGE_INTERP: %PgmImage interpolation property.
+ * @PGM_IMAGE_WRAPPING: %PgmImage wrapping property.
  * @PGM_IMAGE_ASPECT_RATIO: %PgmImage aspect-ratio property.
  * @PGM_IMAGE_BORDER_WIDTH: %PgmImage border width property.
  * @PGM_IMAGE_BORDER_INNER_COLOR: %PgmImage border inner color property.
@@ -125,38 +127,40 @@ typedef enum {
   PGM_DRAWABLE_OPACITY               = 6,
   PGM_DRAWABLE_REGENERATE            = 7,
   /* PgmImage properties */
-  PGM_IMAGE_DATA_BUFFER              = 8,
-  PGM_IMAGE_DATA_GST_BUFFER          = 9,
-  PGM_IMAGE_DATA_PIXBUF              = 10,
-  PGM_IMAGE_DATA_SYSTEM_BUFFER       = 11,
-  PGM_IMAGE_DATA_IMAGE               = 12,
-  PGM_IMAGE_DATA_EMPTY               = 13,
-  PGM_IMAGE_SYSTEM_BUFFER_CONTENT    = 14,
-  PGM_IMAGE_MAPPING_MATRIX           = 15,
-  PGM_IMAGE_ALIGNMENT                = 16,
-  PGM_IMAGE_LAYOUT                   = 17,
-  PGM_IMAGE_INTERP                   = 18,
-  PGM_IMAGE_ASPECT_RATIO             = 19,
-  PGM_IMAGE_BORDER_WIDTH             = 20,
-  PGM_IMAGE_BORDER_INNER_COLOR       = 21,
-  PGM_IMAGE_BORDER_OUTER_COLOR       = 22,
+  PGM_IMAGE_DATA_FILE                = 8,
+  PGM_IMAGE_DATA_BUFFER              = 9,
+  PGM_IMAGE_DATA_GST_BUFFER          = 10,
+  PGM_IMAGE_DATA_PIXBUF              = 11,
+  PGM_IMAGE_DATA_SYSTEM_BUFFER       = 12,
+  PGM_IMAGE_DATA_IMAGE               = 13,
+  PGM_IMAGE_DATA_EMPTY               = 14,
+  PGM_IMAGE_SYSTEM_BUFFER_CONTENT    = 15,
+  PGM_IMAGE_MAPPING_MATRIX           = 16,
+  PGM_IMAGE_ALIGNMENT                = 17,
+  PGM_IMAGE_LAYOUT                   = 18,
+  PGM_IMAGE_INTERP                   = 19,
+  PGM_IMAGE_WRAPPING                 = 20,
+  PGM_IMAGE_ASPECT_RATIO             = 21,
+  PGM_IMAGE_BORDER_WIDTH             = 22,
+  PGM_IMAGE_BORDER_INNER_COLOR       = 23,
+  PGM_IMAGE_BORDER_OUTER_COLOR       = 24,
   /* PgmText properties */
-  PGM_TEXT_LABEL                     = 23,
-  PGM_TEXT_MARKUP                    = 24,
-  PGM_TEXT_FONT_FAMILY               = 25,
-  PGM_TEXT_HEIGHT                    = 26,
-  PGM_TEXT_ELLIPSIZE                 = 27,
-  PGM_TEXT_JUSTIFY                   = 28,
-  PGM_TEXT_ALIGNMENT                 = 29,
-  PGM_TEXT_WRAP                      = 30,
-  PGM_TEXT_GRAVITY                   = 31,
-  PGM_TEXT_STRETCH                   = 32,
-  PGM_TEXT_STYLE                     = 33,
-  PGM_TEXT_VARIANT                   = 34,
-  PGM_TEXT_WEIGHT                    = 35,
-  PGM_TEXT_LINE_SPACING              = 36,
-  PGM_TEXT_OUTLINE_COLOR             = 37,
-  PGM_TEXT_OUTLINE_WIDTH             = 38
+  PGM_TEXT_LABEL                     = 25,
+  PGM_TEXT_MARKUP                    = 26,
+  PGM_TEXT_FONT_FAMILY               = 27,
+  PGM_TEXT_HEIGHT                    = 28,
+  PGM_TEXT_ELLIPSIZE                 = 29,
+  PGM_TEXT_JUSTIFY                   = 30,
+  PGM_TEXT_ALIGNMENT                 = 31,
+  PGM_TEXT_WRAP                      = 32,
+  PGM_TEXT_GRAVITY                   = 33,
+  PGM_TEXT_STRETCH                   = 34,
+  PGM_TEXT_STYLE                     = 35,
+  PGM_TEXT_VARIANT                   = 36,
+  PGM_TEXT_WEIGHT                    = 37,
+  PGM_TEXT_LINE_SPACING              = 38,
+  PGM_TEXT_OUTLINE_COLOR             = 39,
+  PGM_TEXT_OUTLINE_WIDTH             = 40
 } PgmDrawableProperty;
 
 /**
@@ -258,9 +262,11 @@ struct _PgmDrawable {
   /*< private >*/
   /* Mouse picking */
   PgmVec3  press_point;
+  PgmVec3  viewport_press_point;
   guint16  press_mask;
   guint32  pressure;
   guint16  drag_mask;
+  guchar   drag_distance;
   guint32  release_time;
   guint16  release_button;
   gboolean mouse_over;
@@ -430,86 +436,91 @@ struct _PgmDrawableClass {
   gpointer _pgm_reserved[PGM_PADDING];
 };
 
-GType    pgm_drawable_get_type       (void);
+GType    pgm_drawable_get_type          (void);
 
-PgmError pgm_drawable_hide           (PgmDrawable *drawable);
-PgmError pgm_drawable_show           (PgmDrawable *drawable);
-PgmError pgm_drawable_is_visible     (PgmDrawable *drawable,
-                                      gboolean *visible);
+PgmError pgm_drawable_hide              (PgmDrawable *drawable);
+PgmError pgm_drawable_show              (PgmDrawable *drawable);
+PgmError pgm_drawable_is_visible        (PgmDrawable *drawable,
+                                         gboolean *visible);
 
-PgmError pgm_drawable_set_size       (PgmDrawable *drawable,
-                                      gfloat width,
-                                      gfloat height);
-PgmError pgm_drawable_get_size       (PgmDrawable *drawable,
-                                      gfloat *width,
-                                      gfloat *height);
+PgmError pgm_drawable_set_size          (PgmDrawable *drawable,
+                                         gfloat width,
+                                         gfloat height);
+PgmError pgm_drawable_get_size          (PgmDrawable *drawable,
+                                         gfloat *width,
+                                         gfloat *height);
 
-PgmError pgm_drawable_set_position   (PgmDrawable *drawable,
-                                      gfloat x,
-                                      gfloat y,
-                                      gfloat z);
-PgmError pgm_drawable_get_position   (PgmDrawable *drawable,
-                                      gfloat *x,
-                                      gfloat *y,
-                                      gfloat *z);
+PgmError pgm_drawable_set_position      (PgmDrawable *drawable,
+                                         gfloat x,
+                                         gfloat y,
+                                         gfloat z);
+PgmError pgm_drawable_get_position      (PgmDrawable *drawable,
+                                         gfloat *x,
+                                         gfloat *y,
+                                         gfloat *z);
 
-PgmError pgm_drawable_set_rotation_x (PgmDrawable *drawable,
-                                      gfloat angle);
-PgmError pgm_drawable_get_rotation_x (PgmDrawable *drawable,
-                                      gfloat *angle);
+PgmError pgm_drawable_set_rotation_x    (PgmDrawable *drawable,
+                                         gfloat angle);
+PgmError pgm_drawable_get_rotation_x    (PgmDrawable *drawable,
+                                         gfloat *angle);
 
-PgmError pgm_drawable_set_rotation_y (PgmDrawable *drawable,
-                                      gfloat angle);
-PgmError pgm_drawable_get_rotation_y (PgmDrawable *drawable,
-                                      gfloat *angle);
+PgmError pgm_drawable_set_rotation_y    (PgmDrawable *drawable,
+                                         gfloat angle);
+PgmError pgm_drawable_get_rotation_y    (PgmDrawable *drawable,
+                                         gfloat *angle);
 
-PgmError pgm_drawable_set_rotation_z (PgmDrawable *drawable,
-                                      gfloat angle);
-PgmError pgm_drawable_get_rotation_z (PgmDrawable *drawable,
-                                      gfloat *angle);
+PgmError pgm_drawable_set_rotation_z    (PgmDrawable *drawable,
+                                         gfloat angle);
+PgmError pgm_drawable_get_rotation_z    (PgmDrawable *drawable,
+                                         gfloat *angle);
 
-PgmError pgm_drawable_set_fg_color   (PgmDrawable *drawable,
-                                      guchar r,
-                                      guchar g,
-                                      guchar b,
-                                      guchar a);
-PgmError pgm_drawable_get_fg_color   (PgmDrawable *drawable,
-                                      guchar *r,
-                                      guchar *g,
-                                      guchar *b,
-                                      guchar *a);
+PgmError pgm_drawable_set_fg_color      (PgmDrawable *drawable,
+                                         guchar r,
+                                         guchar g,
+                                         guchar b,
+                                         guchar a);
+PgmError pgm_drawable_get_fg_color      (PgmDrawable *drawable,
+                                         guchar *r,
+                                         guchar *g,
+                                         guchar *b,
+                                         guchar *a);
 
-PgmError pgm_drawable_set_bg_color   (PgmDrawable *drawable,
-                                      guchar r,
-                                      guchar g,
-                                      guchar b,
-                                      guchar a);
-PgmError pgm_drawable_get_bg_color   (PgmDrawable *drawable,
-                                      guchar *r,
-                                      guchar *g,
-                                      guchar *b,
-                                      guchar *a);
+PgmError pgm_drawable_set_bg_color      (PgmDrawable *drawable,
+                                         guchar r,
+                                         guchar g,
+                                         guchar b,
+                                         guchar a);
+PgmError pgm_drawable_get_bg_color      (PgmDrawable *drawable,
+                                         guchar *r,
+                                         guchar *g,
+                                         guchar *b,
+                                         guchar *a);
 
-PgmError pgm_drawable_set_opacity    (PgmDrawable *drawable,
-                                      guchar opacity);
-PgmError pgm_drawable_get_opacity    (PgmDrawable *drawable,
-                                      guchar *opacity);
+PgmError pgm_drawable_set_opacity       (PgmDrawable *drawable,
+                                         guchar opacity);
+PgmError pgm_drawable_get_opacity       (PgmDrawable *drawable,
+                                         guchar *opacity);
 
-PgmError pgm_drawable_regenerate     (PgmDrawable *drawable);
+PgmError pgm_drawable_set_drag_distance (PgmDrawable *drawable,
+                                         guchar distance);
+PgmError pgm_drawable_get_drag_distance (PgmDrawable *drawable,
+                                         guchar *distance);
 
-PgmError pgm_drawable_from_canvas    (PgmDrawable *drawable,
-                                      gfloat *x_drawable,
-                                      gfloat *y_drawable,
-                                      gfloat  x_canvas,
-                                      gfloat  y_canvas,
-                                      gfloat  z_canvas);
+PgmError pgm_drawable_regenerate        (PgmDrawable *drawable);
 
-PgmError pgm_drawable_to_canvas      (PgmDrawable *drawable,
-                                      gfloat *x_canvas,
-                                      gfloat *y_canvas,
-                                      gfloat *z_canvas,
-                                      gfloat  x_drawable,
-                                      gfloat  y_drawable);
+PgmError pgm_drawable_from_canvas       (PgmDrawable *drawable,
+                                         gfloat *x_drawable,
+                                         gfloat *y_drawable,
+                                         gfloat  x_canvas,
+                                         gfloat  y_canvas,
+                                         gfloat  z_canvas);
+
+PgmError pgm_drawable_to_canvas         (PgmDrawable *drawable,
+                                         gfloat *x_canvas,
+                                         gfloat *y_canvas,
+                                         gfloat *z_canvas,
+                                         gfloat  x_drawable,
+                                         gfloat  y_drawable);
 
 
 /* Protected methods */
