@@ -36,6 +36,9 @@ GType pgm_button_type_get_type (void);
 #define PGM_TYPE_SCROLL_DIRECTION pgm_scroll_direction_get_type()
 GType pgm_scroll_direction_get_type (void);
 
+#define PGM_TYPE_VIEWPORT_STATE pgm_viewport_state_get_type()
+GType pgm_viewport_state_get_type (void);
+
 /* --- ./pgmimage.h --- */
 #define PGM_TYPE_IMAGE_ALIGNMENT pgm_image_alignment_get_type()
 GType pgm_image_alignment_get_type (void);
