@@ -647,8 +647,8 @@ pgm_image_init (PgmImage *image)
   image->align = PGM_IMAGE_CENTER;
   image->layout = PGM_IMAGE_SCALED;
   image->interp = PGM_IMAGE_BILINEAR;
-  image->wrap_s = PGM_IMAGE_REPEAT;
-  image->wrap_t = PGM_IMAGE_REPEAT;
+  image->wrap_s = PGM_IMAGE_CLAMP;
+  image->wrap_t = PGM_IMAGE_CLAMP;
   image->master = NULL;
   image->slaves = NULL;
   image->border_width = 0.0f;
