@@ -60,7 +60,10 @@ G_BEGIN_DECLS
 /* VOID:BOXED (./pgmmarshal.list:29) */
 #define pgm_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED
 
-/* BOOLEAN:BOXED (./pgmmarshal.list:30) */
+/* VOID:UINT (./pgmmarshal.list:30) */
+#define pgm_marshal_VOID__UINT	g_cclosure_marshal_VOID__UINT
+
+/* BOOLEAN:BOXED (./pgmmarshal.list:31) */
 extern void pgm_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -105,7 +108,50 @@ pgm_marshal_BOOLEAN__BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:OBJECT,OBJECT (./pgmmarshal.list:31) */
+/* VOID:OBJECT,UINT (./pgmmarshal.list:32) */
+extern void pgm_marshal_VOID__OBJECT_UINT (GClosure     *closure,
+                                           GValue       *return_value,
+                                           guint         n_param_values,
+                                           const GValue *param_values,
+                                           gpointer      invocation_hint,
+                                           gpointer      marshal_data);
+void
+pgm_marshal_VOID__OBJECT_UINT (GClosure     *closure,
+                               GValue       *return_value,
+                               guint         n_param_values,
+                               const GValue *param_values,
+                               gpointer      invocation_hint,
+                               gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__OBJECT_UINT) (gpointer     data1,
+                                                  gpointer     arg_1,
+                                                  guint        arg_2,
+                                                  gpointer     data2);
+  register GMarshalFunc_VOID__OBJECT_UINT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__OBJECT_UINT) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_object (param_values + 1),
+            g_marshal_value_peek_uint (param_values + 2),
+            data2);
+}
+
+/* VOID:OBJECT,OBJECT (./pgmmarshal.list:33) */
 extern void pgm_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -148,7 +194,7 @@ pgm_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT,OBJECT,INT (./pgmmarshal.list:32) */
+/* VOID:OBJECT,OBJECT,INT (./pgmmarshal.list:34) */
 extern void pgm_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -193,7 +239,7 @@ pgm_marshal_VOID__OBJECT_OBJECT_INT (GClosure     *closure,
             data2);
 }
 
-/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT (./pgmmarshal.list:33) */
+/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT (./pgmmarshal.list:35) */
 extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT (GClosure     *closure,
                                                               GValue       *return_value,
                                                               guint         n_param_values,
@@ -246,7 +292,7 @@ pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT,UINT (./pgmmarshal.list:34) */
+/* BOOLEAN:FLOAT,FLOAT,FLOAT,ENUM,UINT,UINT (./pgmmarshal.list:36) */
 extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT_UINT (GClosure     *closure,
                                                                    GValue       *return_value,
                                                                    guint         n_param_values,
@@ -301,7 +347,7 @@ pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_ENUM_UINT_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:35) */
+/* BOOLEAN:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:37) */
 extern void pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
@@ -352,7 +398,7 @@ pgm_marshal_BOOLEAN__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* VOID:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:36) */
+/* VOID:FLOAT,FLOAT,FLOAT,UINT (./pgmmarshal.list:38) */
 extern void pgm_marshal_VOID__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -399,7 +445,7 @@ pgm_marshal_VOID__FLOAT_FLOAT_FLOAT_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:UINT,UINT,POINTER (./pgmmarshal.list:37) */
+/* VOID:UINT,UINT,POINTER (./pgmmarshal.list:39) */
 extern void pgm_marshal_VOID__UINT_UINT_POINTER (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
