@@ -89,15 +89,6 @@ pgm_bp_viewport_set_fullscreen (PgmViewport *viewport,
   return PGM_ERROR_OK;
 }
 
-static PgmError
-pgm_bp_viewport_get_fullscreen (PgmViewport *viewport,
-                                gboolean *fullscreen)
-{
-  GST_LOG_OBJECT (viewport, "get_fullscreen");
-
-  return PGM_ERROR_OK;
-}
-
 static PgmError
 pgm_bp_viewport_set_screen_resolution (PgmViewport *viewport,
                                        gint width,
@@ -244,8 +235,6 @@ pgm_bp_viewport_class_init (PgmBpViewportClass *klass)
   viewport_class->get_size = GST_DEBUG_FUNCPTR (pgm_bp_viewport_get_size);
   viewport_class->set_fullscreen =
     GST_DEBUG_FUNCPTR (pgm_bp_viewport_set_fullscreen);
-  viewport_class->get_fullscreen =
-    GST_DEBUG_FUNCPTR (pgm_bp_viewport_get_fullscreen);
   viewport_class->set_screen_resolution =
     GST_DEBUG_FUNCPTR (pgm_bp_viewport_set_screen_resolution);
   viewport_class->get_screen_resolution =
