@@ -1156,7 +1156,8 @@ update_removal_timeout_cb (gpointer data)
 
   /* If the elapsed time since the previous update request rises above one
    * second, remove the auto-update source */
-  if ((current_time.tv_sec - context->update_timestamp.tv_sec) >= 2)
+  if ((current_time.tv_sec - context->update_timestamp.tv_sec) >= 2
+      || context->prevent_update)
     {
       GSource *source;
 
@@ -1483,6 +1484,7 @@ init_context (PgmContext *context)
   /* Auto-update */
   context->update_mutex = g_mutex_new ();
   context->auto_updated = FALSE;
+  context->prevent_update = FALSE;
   g_get_current_time (&context->update_timestamp);
   context->update_tag = 0;
   context->requested_fps = 0;
@@ -1650,6 +1652,10 @@ pgm_context_update (PgmContext *context)
     {
       GSource *source;
 
+      /* Don't add the update source if it's been asked to prevent it */
+      if (G_UNLIKELY (context->prevent_update))
+        goto no_update;
+
       /* Add the update source to the rendering GMainContext. If the user has
        * not specified a framerate through the PGM_GL_FPS environment
        * variable, an idle source blocked on the vsync is attached. Otherwise,
@@ -1679,6 +1685,7 @@ pgm_context_update (PgmContext *context)
       context->auto_updated = TRUE;
     }
 
+ no_update:
   g_mutex_unlock (context->update_mutex);
 }
 
@@ -1711,6 +1718,15 @@ pgm_context_remove_tasks_with_data (PgmContext *context,
   remove_tasks_with_data (context, &context->deferred_task, data);
 }
 
+void
+pgm_context_prevent_update (PgmContext *context,
+                            gboolean prevent)
+{
+  g_mutex_lock (context->update_mutex);
+  context->prevent_update = prevent;
+  g_mutex_unlock (context->update_mutex);
+}
+
 /* FIXME */
 void
 pgm_context_dump_features (PgmContext *context)
