@@ -129,14 +129,18 @@ update_wrapping (PgmGlImage *glimage)
   GST_OBJECT_LOCK (image);
 
   if (image->wrap_s == PGM_IMAGE_CLAMP)
-    texture->wrap_s = PGM_GL_CLAMP_TO_BORDER;
+    texture->wrap_s = PGM_GL_CLAMP_TO_EDGE;
   else if (image->wrap_s == PGM_IMAGE_REPEAT)
     texture->wrap_s = PGM_GL_REPEAT;
+  else if (image->wrap_s == PGM_IMAGE_TRANSPARENT)
+    texture->wrap_s = PGM_GL_CLAMP_TO_BORDER;
 
   if (image->wrap_t == PGM_IMAGE_CLAMP)
-    texture->wrap_t = PGM_GL_CLAMP_TO_BORDER;
+    texture->wrap_t = PGM_GL_CLAMP_TO_EDGE;
   else if (image->wrap_t == PGM_IMAGE_REPEAT)
     texture->wrap_t = PGM_GL_REPEAT;
+  else if (image->wrap_t == PGM_IMAGE_TRANSPARENT)
+    texture->wrap_t = PGM_GL_CLAMP_TO_BORDER;
 
   GST_OBJECT_UNLOCK (image);
 }
