@@ -88,6 +88,7 @@ PgmGlDrawable *pgm_gl_image_new                    (PgmDrawable *drawable,
 void           pgm_gl_image_register               (GTypeModule *module);
 
 void           pgm_gl_image_clear                  (PgmGlImage *glimage);
+void           pgm_gl_image_set_from_file          (PgmGlImage *glimage);
 void           pgm_gl_image_set_from_buffer        (PgmGlImage *glimage);
 void           pgm_gl_image_set_from_gst_buffer    (PgmGlImage *glimage);
 void           pgm_gl_image_set_from_pixbuf        (PgmGlImage *glimage);
@@ -97,6 +98,7 @@ void           pgm_gl_image_set_mapping_matrix     (PgmGlImage *glimage);
 void           pgm_gl_image_set_alignment          (PgmGlImage *glimage);
 void           pgm_gl_image_set_layout             (PgmGlImage *glimage);
 void           pgm_gl_image_set_interp             (PgmGlImage *glimage);
+void           pgm_gl_image_set_wrapping           (PgmGlImage *glimage);
 void           pgm_gl_image_set_aspect_ratio       (PgmGlImage *glimage);
 void           pgm_gl_image_set_border_width       (PgmGlImage *glimage);
 void           pgm_gl_image_set_border_inner_color (PgmGlImage *glimage);
