@@ -878,6 +878,35 @@ pgm_gl_viewport_set_fullscreen (PgmViewport *viewport,
   return PGM_ERROR_OK;
 }
 
+static PgmError
+pgm_gl_viewport_set_iconified (PgmViewport *viewport,
+                               gboolean iconified)
+{
+  PgmGlViewport *glviewport = PGM_GL_VIEWPORT (viewport);
+  PgmContextTask *task;
+
+  GST_DEBUG_OBJECT (glviewport, "set_iconified");
+
+  task = pgm_context_task_new (PGM_CONTEXT_ICONIFICATION, NULL);
+  pgm_context_push_immediate_task (glviewport->context, task);
+
+  return PGM_ERROR_OK;
+}
+
+static PgmError
+pgm_gl_viewport_focus (PgmViewport *viewport)
+{
+  PgmGlViewport *glviewport = PGM_GL_VIEWPORT (viewport);
+  PgmContextTask *task;
+
+  GST_DEBUG_OBJECT (glviewport, "present");
+
+  task = pgm_context_task_new (PGM_CONTEXT_FOCUS, NULL);
+  pgm_context_push_immediate_task (glviewport->context, task);
+
+  return PGM_ERROR_OK;
+}
+
 static PgmError
 pgm_gl_viewport_get_screen_resolution (PgmViewport *viewport,
                                        gint *width,
@@ -1208,6 +1237,9 @@ pgm_gl_viewport_class_init (PgmGlViewportClass *klass)
     GST_DEBUG_FUNCPTR (pgm_gl_viewport_set_opacity);
   viewport_class->set_fullscreen =
     GST_DEBUG_FUNCPTR (pgm_gl_viewport_set_fullscreen);
+  viewport_class->set_iconified =
+    GST_DEBUG_FUNCPTR (pgm_gl_viewport_set_iconified);
+  viewport_class->focus = GST_DEBUG_FUNCPTR (pgm_gl_viewport_focus);
   viewport_class->get_screen_resolution =
     GST_DEBUG_FUNCPTR (pgm_gl_viewport_get_screen_resolution);
   viewport_class->get_screen_size_mm =
