@@ -1600,12 +1600,25 @@ dispatch_x_events (PgmBackend *backend)
 
           if (! (glxbackend->state & PGM_VIEWPORT_ICONIFIED))
             {
+              pgm_context_prevent_update (backend->context, TRUE);
               glxbackend->state |= PGM_VIEWPORT_ICONIFIED;
               push_state_event (backend, PGM_VIEWPORT_ICONIFIED,
                                 glxbackend->state);
             }
           break;
 
+          /* --- Visibility notify event --- */
+        case VisibilityNotify:
+          GST_DEBUG_OBJECT (glxbackend, "VisibilityNotify event: (state=%d)",
+                            xevent.xvisibility.state);
+
+          if (xevent.xvisibility.state == VisibilityUnobscured
+              || xevent.xvisibility.state == VisibilityPartiallyObscured)
+            pgm_context_prevent_update (backend->context, FALSE);
+          else if (xevent.xvisibility.state == VisibilityFullyObscured)
+            pgm_context_prevent_update (backend->context, TRUE);
+          break;
+
           /* --- Selection notify event --- */
         case SelectionNotify:
           GST_DEBUG_OBJECT (glxbackend, "SelectionNotify event: "
@@ -1712,7 +1725,8 @@ add_event_source (PgmGlxBackend *glxbackend)
   XSelectInput (glxbackend->dpy, glxbackend->win,
                 KeyPressMask | KeyReleaseMask | ButtonPressMask
                 | ButtonReleaseMask | StructureNotifyMask | ExposureMask
-                | PointerMotionMask | PropertyChangeMask);
+                | PointerMotionMask | PropertyChangeMask
+                | VisibilityChangeMask);
 
   /* Create and initialize the event handling dedicated source */
   source = (PgmGlxBackendSource *)
