@@ -493,8 +493,8 @@ init_texture (PgmTexture *texture)
   /* Parameters */
   texture->matrix = pgm_mat4x4_new_identity ();
   texture->filter = PGM_GL_LINEAR;
-  texture->wrap_s = PGM_GL_REPEAT;
-  texture->wrap_t = PGM_GL_REPEAT ;
+  texture->wrap_s = PGM_GL_CLAMP_TO_EDGE;
+  texture->wrap_t = PGM_GL_CLAMP_TO_EDGE;
 
   /* State flags */
   texture->flags = PGM_TEXTURE_IDENTITY_MATRIX;
