@@ -128,15 +128,21 @@ update_wrapping (PgmGlesImage *glesimage)
 
   GST_OBJECT_LOCK (image);
 
+  /* No CLAMP_TO_BORDER in OpenGL ES */
+
   if (image->wrap_s == PGM_IMAGE_CLAMP)
     glestexture->wrap_s = PGM_GLES_CLAMP_TO_EDGE;
   else if (image->wrap_s == PGM_IMAGE_REPEAT)
     glestexture->wrap_s = PGM_GLES_REPEAT;
+  else if (image->wrap_s == PGM_IMAGE_TRANSPARENT)
+    glestexture->wrap_s = PGM_GLES_CLAMP_TO_EDGE;
 
   if (image->wrap_t == PGM_IMAGE_CLAMP)
     glestexture->wrap_t = PGM_GLES_CLAMP_TO_EDGE;
   else if (image->wrap_t == PGM_IMAGE_REPEAT)
     glestexture->wrap_t = PGM_GLES_REPEAT;
+  else if (image->wrap_t == PGM_IMAGE_TRANSPARENT)
+    glestexture->wrap_t = PGM_GLES_CLAMP_TO_EDGE;
 
   GST_OBJECT_UNLOCK (image);
 }
