@@ -721,6 +721,11 @@ update_pixmap (PgmGlesText *glestext)
   unpremultiply_alpha ((guint32*) glestext->buffer, glestext->width,
                        glestext->height);
 
+  /* Update texture */
+ pgm_gles_texture_set_buffer (glestext->texture, glestext->buffer,
+                              PGM_IMAGE_BGRA, glestext->width, glestext->height,
+                              glestext->size, 0);
+
   /* Request texture upload */
   task = pgm_gles_context_task_new (PGM_GLES_CONTEXT_UPLOAD_TEXTURE,
                                     glestext->texture);
